@@ -1,7 +1,7 @@
-import mock
 import os
-from six.moves import http_client
 import unittest
+import mock
+from six.moves import http_client
 import click
 import six
 from click import testing
@@ -18,6 +18,7 @@ BUILD_CONTAINER_TAG = 'build-container-tag'
 BUILD_CONTAINER_FQDN_IMAGE = REGISTRY + '/' + BUILD_CONTAINER_IMAGE + ':' + BUILD_CONTAINER_TAG
 
 ENV = ["KEY1=VAL1", "KEY2=VAL2"]
+ENV_FILE_PATH = '/home/envfile.env'
 
 SKIPPER_CONF_CONTAINER_CONTEXT = '/some/context'
 SKIPPER_CONF_BUILD_CONTAINER_IMAGE = 'skipper-conf-build-container-image'
@@ -53,6 +54,15 @@ SKIPPER_CONF_WITH_ENV = {
     },
     'env': CONFIG_ENV
 }
+SKIPPER_CONF_WITH_ENV_FILE = {
+    'registry': REGISTRY,
+    'build-container-image': SKIPPER_CONF_BUILD_CONTAINER_IMAGE,
+    'build-container-tag': SKIPPER_CONF_BUILD_CONTAINER_TAG,
+    'make': {
+        'makefile': SKIPPER_CONF_MAKEFILE,
+    },
+    'env-file': ENV_FILE_PATH
+}
 SKIPPER_CONF_WITH_ENV_LIST = {
     'registry': REGISTRY,
     'build-container-image': SKIPPER_CONF_BUILD_CONTAINER_IMAGE,
@@ -293,8 +303,8 @@ class TestCLI(unittest.TestCase):
                        'Dockerfile.build-container-image',
                        SKIPPER_CONF_CONTAINER_CONTEXT]),
             mock.call(['make'] + make_params, fqdn_image='build-container-image', environment=[],
-                      interactive=False, name=None, net='host', volumes=None, workdir=None,
-                      use_cache=False, workspace=None),
+                      interactive=False, name=None, net=None, publish=(), volumes=None, workdir=None,
+                      use_cache=False, workspace=None, env_file=None),
         ]
         skipper_runner_run_mock.assert_has_calls(expected_commands)
 
@@ -1029,8 +1039,10 @@ class TestCLI(unittest.TestCase):
         )
         expected_image_name = 'build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_image_name, environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value=''))
     @mock.patch('requests.get', autospec=True)
@@ -1054,8 +1066,10 @@ class TestCLI(unittest.TestCase):
         )
         expected_image_name = 'registry.io:5000/build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_image_name, environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value=''))
     @mock.patch('skipper.runner.run', mock.MagicMock(autospec=True))
@@ -1093,8 +1107,10 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'skipper-conf-build-container-image:skipper-conf-build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1113,8 +1129,41 @@ class TestCLI(unittest.TestCase):
         env = ["%s=%s" % (key, value) for key, value in six.iteritems(CONFIG_ENV_EVALUATION)]
         expected_fqdn_image = 'skipper-conf-build-container-image:skipper-conf-build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=env,
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
+
+    @mock.patch('__builtin__.open', mock.MagicMock(create=True))
+    @mock.patch('os.path.exists',
+                mock.MagicMock(autospec=True, return_value=True))
+    @mock.patch('yaml.safe_load', mock.MagicMock(
+        autospec=True, return_value=SKIPPER_CONF_WITH_ENV_FILE))
+    @mock.patch('subprocess.check_output',
+                mock.MagicMock(autospec=True, return_value='1234567\n'))
+    @mock.patch('skipper.runner.run', autospec=True)
+    def test_run_with_defaults_and_env_from_env_file(
+            self,
+            skipper_runner_run_mock
+    ):
+        command = ['ls', '-l']
+        run_params = command
+        self._invoke_cli(
+            defaults=config.load_defaults(),
+            subcmd='run',
+            subcmd_params=run_params
+        )
+        expected_fqdn_image = 'skipper-conf-build-container-image:skipper-conf-build-container-tag'
+        skipper_runner_run_mock.assert_called_once_with(command,
+                                                        fqdn_image=expected_fqdn_image,
+                                                        environment=[],
+                                                        interactive=False,
+                                                        name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None,
+                                                        workspace=None,
+                                                        use_cache=False,
+                                                        env_file=ENV_FILE_PATH)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1133,8 +1182,10 @@ class TestCLI(unittest.TestCase):
         env = ["%s=%s" % (key, value) for key, value in six.iteritems(CONFIG_ENV_EVALUATION)] + ENV
         expected_fqdn_image = 'skipper-conf-build-container-image:skipper-conf-build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=env,
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1154,8 +1205,10 @@ class TestCLI(unittest.TestCase):
         env = ['key1=value1'] + ENV
         expected_fqdn_image = 'skipper-conf-build-container-image:skipper-conf-build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=env,
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1175,8 +1228,10 @@ class TestCLI(unittest.TestCase):
         env = ['key1=value1', 'key2=value2'] + ENV
         expected_fqdn_image = 'skipper-conf-build-container-image:skipper-conf-build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=env,
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1207,8 +1262,10 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=ENV,
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value='1234567\n'))
     @mock.patch('skipper.runner.run', autospec=True)
@@ -1223,8 +1280,9 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=[],
-                                                        interactive=True, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=True, name=None, net=None, publish=(), volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
         del os.environ['SKIPPER_INTERACTIVE']
 
     @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value='1234567\n'))
@@ -1240,8 +1298,10 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
         del os.environ['SKIPPER_INTERACTIVE']
 
     @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value='1234567\n'))
@@ -1256,8 +1316,9 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=[],
-                                                        interactive=True, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=True, name=None, net=None, publish=(), volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value=''))
     @mock.patch('skipper.runner.run', autospec=True, return_value=0)
@@ -1274,8 +1335,8 @@ class TestCLI(unittest.TestCase):
             mock.call(['build', '--network=host', '-t', 'build-container-image', '-f',
                        'Dockerfile.build-container-image', '.']),
             mock.call(command, fqdn_image='build-container-image', environment=[],
-                      interactive=False, name=None, net='host', volumes=None, workdir=None, workspace=None,
-                      use_cache=False),
+                      interactive=False, name=None, net=None, publish=(), volumes=None, workdir=None, workspace=None,
+                      use_cache=False, env_file=None),
         ]
         skipper_runner_run_mock.assert_has_calls(expected_commands)
 
@@ -1292,8 +1353,8 @@ class TestCLI(unittest.TestCase):
         )
         expected_commands = [
             mock.call(command, fqdn_image='build-container-image', environment=[],
-                      interactive=False, name=None, net='host', volumes=None, workdir=None, workspace=None,
-                      use_cache=True),
+                      interactive=False, name=None, net=None, publish=(), volumes=None, workdir=None, workspace=None,
+                      use_cache=True, env_file=None),
         ]
         skipper_runner_run_mock.assert_has_calls(expected_commands)
 
@@ -1312,8 +1373,144 @@ class TestCLI(unittest.TestCase):
         expected_fqdn_image = 'build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=[],
                                                         interactive=False, name=None, net='non-default-net',
-                                                        volumes=None, workdir=None, workspace=None,
-                                                        use_cache=False)
+                                                        publish=(), volumes=None, workdir=None, workspace=None,
+                                                        use_cache=False, env_file=None)
+
+    @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value='1234567'))
+    @mock.patch('skipper.runner.run', autospec=True)
+    def test_run_with_publish_single_port(self, skipper_runner_run_mock):
+        global_params = self.global_params
+        global_params += ['--build-container-net', 'non-default-net']
+
+        makefile = 'Makefile'
+        target = 'all'
+        make_params = ['-p', '123:123', '-f', makefile, target]
+
+        self._invoke_cli(
+            global_params=global_params,
+            subcmd='make',
+            subcmd_params=make_params
+        )
+
+        expected_command = ['make', '-f', makefile, target]
+
+        expected_fqdn_image = 'build-container-image:build-container-tag'
+        skipper_runner_run_mock.assert_called_once_with(expected_command, fqdn_image=expected_fqdn_image,
+                                                        environment=[],
+                                                        interactive=False, name=None, net=u'non-default-net',
+                                                        publish=(u'123:123',), volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
+
+    @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value='1234567'))
+    @mock.patch('skipper.runner.run', autospec=True)
+    def test_run_with_publish_multiple_ports(self, skipper_runner_run_mock):
+        global_params = self.global_params
+        global_params += ['--build-container-net', 'non-default-net']
+
+        makefile = 'Makefile'
+        target = 'all'
+        make_params = ['-p', '123:123', '-p', '12:12', '-f', makefile, target]
+
+        self._invoke_cli(
+            global_params=global_params,
+            subcmd='make',
+            subcmd_params=make_params
+        )
+
+        expected_command = ['make', '-f', makefile, target]
+
+        expected_fqdn_image = 'build-container-image:build-container-tag'
+        skipper_runner_run_mock.assert_called_once_with(expected_command, fqdn_image=expected_fqdn_image,
+                                                        environment=[],
+                                                        interactive=False, name=None, net=u'non-default-net',
+                                                        publish=('123:123', '12:12'), volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
+
+    @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value='1234567'))
+    @mock.patch('skipper.runner.run', autospec=True)
+    def test_run_with_publish_port_range(self, skipper_runner_run_mock):
+        global_params = self.global_params
+        global_params += ['--build-container-net', 'non-default-net']
+
+        makefile = 'Makefile'
+        target = 'all'
+        make_params = ['-p', '123:123', '-p', '12-13:12-13', '-f', makefile, target]
+
+        self._invoke_cli(
+            global_params=global_params,
+            subcmd='make',
+            subcmd_params=make_params
+        )
+
+        expected_command = ['make', '-f', makefile, target]
+
+        expected_fqdn_image = 'build-container-image:build-container-tag'
+        skipper_runner_run_mock.assert_called_once_with(expected_command, fqdn_image=expected_fqdn_image,
+                                                        environment=[],
+                                                        interactive=False, name=None, net=u'non-default-net',
+                                                        publish=('123:123', '12-13:12-13'), volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
+
+    def test_run_with_publish_textual_port(self):
+        global_params = self.global_params
+        global_params += ['--build-container-net', 'non-default-net']
+
+        makefile = 'Makefile'
+        target = 'all'
+        make_params = ['-p', '123:a1', '-p', '12:12', '-f', makefile, target]
+
+        result = self._invoke_cli(global_params=global_params, subcmd='make', subcmd_params=make_params)
+        self.assertIsInstance(result.exception, click.BadParameter)
+        self.assertEqual("Publish need to be in format port:port or port-port:port-port", result.exception.message)
+        self.assertEqual(-1, result.exit_code)
+
+    def test_run_with_publish_textual_port_range(self):
+        global_params = self.global_params
+        global_params += ['--build-container-net', 'non-default-net']
+
+        makefile = 'Makefile'
+        target = 'all'
+        make_params = ['-p', '123-1:1-a1', '-p', '12:12', '-f', makefile, target]
+
+        result = self._invoke_cli(global_params=global_params, subcmd='make', subcmd_params=make_params)
+        self.assertIsInstance(result.exception, click.BadParameter)
+        self.assertEqual("Publish need to be in format port:port or port-port:port-port", result.exception.message)
+        self.assertEqual(-1, result.exit_code)
+
+    def test_run_with_invalid_port_range(self):
+        global_params = self.global_params
+        global_params += ['--build-container-net', 'non-default-net']
+
+        makefile = 'Makefile'
+        target = 'all'
+        make_params = ['-p', '15-25:25-15', '-p', '12:12', '-f', makefile, target]
+
+        result = self._invoke_cli(global_params=global_params, subcmd='make', subcmd_params=make_params)
+        self.assertIsInstance(result.exception, click.BadParameter)
+        self.assertEqual("Invalid port range: 25 should be bigger than 15", result.exception.message)
+        self.assertEqual(-1, result.exit_code)
+
+        make_params = ['-p', '25-15:15-25', '-p', '12:12', '-f', makefile, target]
+        result = self._invoke_cli(global_params=global_params, subcmd='make', subcmd_params=make_params)
+        self.assertIsInstance(result.exception, click.BadParameter)
+        self.assertEqual("Invalid port range: 25 should be bigger than 15", result.exception.message)
+        self.assertEqual(-1, result.exit_code)
+
+    def test_run_with_publish_out_of_range_port(self):
+        global_params = self.global_params
+        global_params += ['--build-container-net', 'non-default-net']
+
+        makefile = 'Makefile'
+        target = 'all'
+        make_params = ['-p', '123:1', '-p', '12:121111111', '-f', makefile, target]
+
+        result = self._invoke_cli(global_params=global_params, subcmd='make', subcmd_params=make_params)
+        self.assertIsInstance(result.exception, click.BadParameter)
+        self.assertEqual("Invalid port number: port 121111111 is out of range", result.exception.message)
+        self.assertEqual(-1, result.exit_code)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1330,9 +1527,9 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'skipper-conf-build-container-image:skipper-conf-build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=[],
-                                                        interactive=False, name=None, net='host',
+                                                        interactive=False, name=None, net=None, publish=(),
                                                         volumes=['volume1', 'volume2'], workspace=None,
-                                                        workdir=None, use_cache=False)
+                                                        workdir=None, use_cache=False, env_file=None)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1349,8 +1546,10 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'skipper-conf-build-container-image:skipper-conf-build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir='test-workdir', workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir='test-workdir', workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1367,8 +1566,10 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'skipper-conf-build-container-image:skipper-conf-build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace="/test/workspace", use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace="/test/workspace", use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1386,8 +1587,10 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'skipper-conf-build-container-image:1234567'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, use_cache=False, workspace=None)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, use_cache=False, workspace=None,
+                                                        env_file=None)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1405,8 +1608,10 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'skipper-conf-build-container-image:1234567'
         skipper_runner_run_mock.assert_called_once_with(command, fqdn_image=expected_fqdn_image, environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value='1234567\n'))
     @mock.patch('skipper.runner.run', autospec=True)
@@ -1423,8 +1628,10 @@ class TestCLI(unittest.TestCase):
         expected_fqdn_image = 'build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(expected_command, fqdn_image=expected_fqdn_image,
                                                         environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value='1234567\n'))
     @mock.patch('skipper.runner.run', autospec=True)
@@ -1437,8 +1644,10 @@ class TestCLI(unittest.TestCase):
         expected_fqdn_image = 'build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(expected_command, fqdn_image=expected_fqdn_image,
                                                         environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value='1234567\n'))
     @mock.patch('skipper.runner.run', autospec=True)
@@ -1454,8 +1663,10 @@ class TestCLI(unittest.TestCase):
         expected_fqdn_image = 'build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(expected_command, fqdn_image=expected_fqdn_image,
                                                         environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('__builtin__.open', mock.MagicMock(create=True))
     @mock.patch('os.path.exists', mock.MagicMock(autospec=True, return_value=True))
@@ -1475,8 +1686,10 @@ class TestCLI(unittest.TestCase):
         expected_fqdn_image = 'skipper-conf-build-container-image:skipper-conf-build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(expected_command, fqdn_image=expected_fqdn_image,
                                                         environment=[],
-                                                        interactive=False, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=False, name=None, net=None, publish=(),
+                                                        volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('subprocess.check_output', mock.MagicMock(autospec=True, return_value=''))
     @mock.patch('skipper.runner.run', autospec=True, return_value=0)
@@ -1494,8 +1707,8 @@ class TestCLI(unittest.TestCase):
             mock.call(['build', '--network=host', '-t', 'build-container-image', '-f',
                        'Dockerfile.build-container-image', '.']),
             mock.call(['make'] + make_params, fqdn_image='build-container-image', environment=[],
-                      interactive=False, name=None, net='host', volumes=None, workdir=None, workspace=None,
-                      use_cache=False),
+                      interactive=False, name=None, net=None, publish=(), volumes=None, workdir=None, workspace=None,
+                      use_cache=False, env_file=None),
         ]
         skipper_runner_run_mock.assert_has_calls(expected_commands)
 
@@ -1508,8 +1721,9 @@ class TestCLI(unittest.TestCase):
         )
         expected_fqdn_image = 'build-container-image:build-container-tag'
         skipper_runner_run_mock.assert_called_once_with(['bash'], fqdn_image=expected_fqdn_image, environment=[],
-                                                        interactive=True, name=None, net='host', volumes=None,
-                                                        workdir=None, workspace=None, use_cache=False)
+                                                        interactive=True, name=None, net=None, publish=(), volumes=None,
+                                                        workdir=None, workspace=None, use_cache=False,
+                                                        env_file=None)
 
     @mock.patch('click.echo', autospec=True)
     @mock.patch('skipper.cli.get_distribution', autospec=True)
